Block class

Annotations
  • @freezed

Constructors

Block({required String id, required String content, @Default.new([]) List<Block> children, @Default.new(false) bool isCollapsed, required DateTime createdAt, required DateTime updatedAt})
const
factory
Block.create({String? id, required String content, List<Block>? children, bool? isCollapsed})
factory
Block.fromJson(Map<String, dynamic> json)
factory

Properties

hasChildren bool
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalBlocks int
no setter

Methods

findBlockById(String blockId) Block?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited