DraggableBlockWidget class
A draggable wrapper around BlockWidget that enables drag-and-drop reordering.
Provides three drop zones: before, after, and as-child. All BlockWidget customization parameters are passed through.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- DraggableBlockWidget
Constructors
- DraggableBlockWidget({Key? key, required Block block, int depth = 0, bool keyboardShortcutsEnabled = true, BlockStyle style = const BlockStyle(), Widget blockBuilder(BuildContext context, Block block)?, Widget editingBlockBuilder(BuildContext context, Block block, TextEditingController controller, FocusNode focusNode, VoidCallback onSubmitted)?, Widget bulletBuilder(BuildContext context, Block block, bool hasChildren, bool isCollapsed, VoidCallback? onToggle)?, InputDecoration textFieldDecorationBuilder(BuildContext context)?, Widget dragFeedbackBuilder(BuildContext context, Block block)?, Widget dropZoneBuilder(BuildContext context, bool isHighlighted, double indent)?})
-
const
Properties
- block → Block
-
final
- blockBuilder → Widget Function(BuildContext context, Block block)?
-
final
- bulletBuilder → Widget Function(BuildContext context, Block block, bool hasChildren, bool isCollapsed, VoidCallback? onToggle)?
-
final
- depth → int
-
final
- dragFeedbackBuilder → Widget Function(BuildContext context, Block block)?
-
Custom builder for drag feedback widget.
If null, a lightweight, platform-agnostic feedback widget is used.
final
- dropZoneBuilder → Widget Function(BuildContext context, bool isHighlighted, double indent)?
-
Custom builder for drop zone indicators.
Parameters: context, isHighlighted, indent.
If null, uses a simple animated bar.
final
- editingBlockBuilder → Widget Function(BuildContext context, Block block, TextEditingController controller, FocusNode focusNode, VoidCallback onSubmitted)?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- keyboardShortcutsEnabled → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- style → BlockStyle
-
final
- textFieldDecorationBuilder → InputDecoration Function(BuildContext context)?
-
final
Methods
-
createElement(
) → ConsumerStatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → ConsumerState< DraggableBlockWidget> - Creates the mutable state for this widget at a given location in the tree.
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited