DropTarget class
Constructors
- DropTarget({required String? targetParentId, required int targetIndex, required DropPosition position})
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- position → DropPosition
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- targetIndex → int
-
final
- targetParentId → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited